@@ -1,5 +1,5 @@
-suppressPackageStartupMessages(library(simrel))
-suppressPackageStartupMessages(library(testthat))
+library(simrel)
+library(testthat)
 
 context("Testing Custom Tests.")
 
@@ -7,7 +7,7 @@ testthat::test_that(
   "Test expect_subset", {
     expect_success(expect_subset(names(mtcars), c("mpg", "hp")))
     expect_error(expect_subset(list(1, 2, 3), list(1, 2, 3, 4)),
-                 regexp = "does not contain")
+                 class = "expectation_failure")
     expect_success(expect_subset(1:5, 2:4))
     expect_success(expect_subset(LETTERS, toupper(letters)))
   }
